<h1 align="center"  style="font-family: Courier, serif;">
  <a href="https://github.com/TINYT1ME/LogicCircuit/"><img src="https://i.postimg.cc/Gp3Cj8vM/logo.png" width="40" title="LogicCircuit"></a>
  Logic Circuit
</h1>

[![platforms](https://img.shields.io/badge/platforms-Windows%20%7C%20Mac%20%7C%20Linux-%23808080--%2332cd32)](https://github.com/TINYT1ME/GoodUSB/actions)
<br>
**LogicCircuit** is a program that helps build simple circuits using logic gates. It is meant to teach people the basics of how logic gates work.

---

## 📃 Table of Content

- [Table of Content](#-Table-of-Content)
- [Example](#-Example)
- [Installation](#-Installation)
- [How To](#-How-To)
- [Future](#-Future)
- [License](#-License)

---

## 🟢 Example
<a href="https://github.com/TINYT1ME/LogicCircuit/"><img src="https://i.postimg.cc/vBkwM0kj/example.gif"  title="Example"></a>

---

## 📦 Installation

### ➡️ `pip3 install LogicCircuit` ⬅️

---

## ❓ How To

|   | Gate  | Switch  | Led  | Wire  |
| ------------ | ------------ | ------------ | ------------ | ------------ |
| Create  | Left click logic type(bottom). Press anywhere to place  | Left click green "+Switch" Button  | Left click green "+LED" Button  | Left click output gate by pressing on it. Press anywhere on screen while output gate selected to create "bends" to wire. Left click on any gates and leds input square  |
| Delete  |  Right click on gate |  Left click red "-Switch" Button  |  Left click red "-LED" Button | Wires will automatically when connected gate, switch, or led is deleted   |
| Modify  | N/A  |  Middle press on switch | N/A  | N/A  |



---


### 👽 Future

- Main Menu
- Save Project
- Tutorial

---

### ⚖️ License

MIT

---
